@@ -85,8 +85,8 @@
 database_type='Psycopg'
 __doc__='''%s Database Connection
 
-$Id: DA.py,v 1.15 2001/11/14 00:18:25 fog Exp $''' % database_type
-__version__='$Revision: 1.15 $'[11:-2]
+$Id: DA.py,v 1.15.2.2 2002/03/27 15:40:26 fog Exp $''' % database_type
+__version__='$Revision: 1.15.2.2 $'[11:-2]
 
 from db import DB
 import Shared.DC.ZRDB.Connection, sys, DABase
@@ -98,6 +98,12 @@ from DateTime import DateTime
 import time
 from psycopg import new_type, register_type, DATETIME, TIME, DATE, INTERVAL
 
+try:
+    from App.Dialogs import MessageDialog
+except:
+    pass
+
+
 manage_addZPsycopgConnectionForm = HTMLFile('connectionAdd', globals())
 def manage_addZPsycopgConnection(self, id, title,
                                  connection_string, zdatetime=None,
@@ -107,12 +113,12 @@ def manage_addZPsycopgConnection(self, id, title,
                                    check))
     if REQUEST is not None: return self.manage_main(self,REQUEST)
 
+
 # Convert an ISO timestamp string from postgres to a DateTime(zope version)
 # object.
 def cast_DateTime(str):
     return DateTime(str[:-3])
 
-
 # Convert an ISO date string from postgres to a DateTime(zope version)
 # object.
 def cast_Date(str):
@@ -126,13 +132,13 @@ def cast_Time(str):
                                   time.localtime(time.time())[:3]+
                                   time.strptime(str, "%H:%M:%S")[3:]))
 
-
 # Convert a time string from postgres to a DateTime(zope version) object.
 # WARNING: We set the day as the epoch day (1970-01-01) since this
 # DateTime does not support time deltas. (EXPERIMENTAL USE WITH CARE!)
 def cast_Interval(str):
     return str
 
+
 class Connection(DABase.Connection):
     "The connection class."
     database_type = database_type
@@ -140,8 +146,32 @@ class Connection(DABase.Connection):
     meta_type = title = 'Z %s Database Connection' % database_type
     icon = 'misc_/Z%sDA/conn' % database_type
 
-    zdatetime=None
-    
+    def __init__(self, id, title, connection_string, zdatetime, check=None):
+        self.zdatetime=zdatetime
+        self.id=str(id)
+        self.edit(title, connection_string, zdatetime, check)
+
+    def edit(self, title, connection_string, zdatetime, check=1):
+        self.title=title
+        self.connection_string=connection_string
+        self.zdatetime=zdatetime
+        self.set_type_casts()
+        if check: self.connect(connection_string)
+
+    manage_properties=HTMLFile('connectionEdit', globals())
+
+    def manage_edit(self, title, connection_string,
+                    zdatetime=None, check=None, REQUEST=None):
+        """Change connection
+        """
+        self.edit(title, connection_string, zdatetime, check=None)
+        if REQUEST is not None:
+            return MessageDialog(
+                title='Edited',
+                message='<strong>%s</strong> has been edited.' % self.id,
+                action ='./manage_main',
+                )
+        
     def set_type_casts(self):
         "Make changes to psycopg default typecast list"
         if self.zdatetime:
