@@ -21,12 +21,17 @@
 
 /*
  * cursor.c - defines the cursor object DBAPI 2.0
- * $Id: cursor.c,v 1.102.2.5 2002/03/27 15:40:26 fog Exp $
+ * $Id: cursor.c,v 1.102.2.6 2002/04/21 22:58:52 fog Exp $
  */
 
 #include <assert.h>
 
+#ifdef _WIN32
+#include "config32.h"
+#else
 #include "config.h"
+#endif
+
 #include "module.h"
 #include "typemod.h"
 
@@ -1674,7 +1679,11 @@ static char Cusrtype__doc__[] =
 "used to manage the context of a fetch operation.";
 
 static PyTypeObject Curstype = {
+#ifndef _WIN32
     PyObject_HEAD_INIT(&PyType_Type)
+#else
+    PyObject_HEAD_INIT(NULL)
+#endif
     0,				       /*ob_size*/
     "cursor",              /*tp_name*/
     sizeof(cursobject),    /*tp_basicsize*/
@@ -1711,6 +1720,11 @@ cursobject *
 new_psyco_cursobject(connobject *conn, connkeeper *keeper)
 {
     cursobject *self;
+
+#ifdef _WIN32
+    /* For MSVC workaround */
+    Curstype.ob_type = &PyType_Type;
+#endif
     
     Dprintf("new_psyco_cursobject(): new cursor, keeper = %p\n", keeper);
 
