@@ -21,12 +21,17 @@
 
 /*
  * module.c -- defines the module interface to DBAPI 2.0
- * $Id: module.c,v 1.38 2001/10/29 17:57:58 fog Exp $
+ * $Id: module.c,v 1.38.2.1 2002/04/21 22:58:52 fog Exp $
  */
 
 #include <time.h>
 
+#ifdef _WIN32
+#include "config32.h"
+#else
 #include "config.h"
+#endif
+
 #include "module.h"
 #include "typeobj.h"
 #include "typemod.h"
