@@ -21,7 +21,7 @@
 
 /*
  * module.h -- defines constants needed by the module interface DBAPI 2.0
- * $Id: module.h,v 1.48 2001/10/30 20:13:57 mcm Exp $
+ * $Id: module.h,v 1.48.2.1 2002/04/21 22:58:52 fog Exp $
 */
 
 #ifndef __PSYCOPG_MODULE__
@@ -30,7 +30,24 @@
 #include <stdio.h>
 #include <libpq-fe.h>
 #include <time.h>
+#ifndef _WIN32
 #include <pthread.h>
+#else
+#include <windows.h>
+#define pthread_mutex_t HANDLE
+#define pthread_condvar_t HANDLE
+#define pthread_mutex_lock(object) WaitForSingleObject(object, INFINITE)
+#define pthread_mutex_unlock(object) ReleaseMutex(object)
+#define pthread_mutex_destroy(ref) (CloseHandle(ref))
+
+static int pthread_mutex_init(pthread_mutex_t *mutex, void* temp)
+{
+  *mutex=CreateMutex(NULL, FALSE, NULL);
+  return 0;
+}
+#define inline
+
+#endif
 #include <Python.h>
 #include <structmember.h>
 #include <mxDateTime.h>
@@ -102,7 +119,7 @@ typedef struct {
     PGconn          *pgconn;
     pthread_mutex_t  lock;
     int              refcnt;
-    int              status; 
+    int              status;
 } connkeeper;
 
 
