@@ -20,10 +20,12 @@
 
 /*
  * typemod.c -- types available to the psycopg module
- * $Id: typemod.c,v 1.9.2.1 2002/04/05 10:45:40 fog Exp $
+ * $Id: typemod.c,v 1.9.2.3 2002/04/23 17:37:21 fog Exp $
  */
 
+#ifndef _WIN32
 #include <unistd.h>
+#endif
 #include <assert.h>
 
 #include "module.h"
@@ -90,7 +92,11 @@ static char psyco_DateTimeObject__doc__[] =
 "Object to pass (in a portable way) dates and times to the database.";
 
 PyTypeObject psyco_DateTimeObject_Type = {
+#ifndef _WIN32
     PyObject_HEAD_INIT(&PyType_Type)
+#else
+    PyObject_HEAD_INIT(NULL)
+#endif
     0,				                    /*ob_size*/
     "datetime",                         /*tp_name*/
     sizeof(psyco_DateTimeObject),		/*tp_basicsize*/
@@ -119,7 +125,12 @@ static PyObject *
 new_psyco_datetimeobject(PyObject *datetime, int type)
 {
     psyco_DateTimeObject *obj;
-    
+
+#ifdef _WIN32
+    /* For MSVC workaround */
+    psyco_DateTimeObject_Type.ob_type = &PyType_Type;
+#endif
+
     obj = PyObject_NEW(psyco_DateTimeObject, &psyco_DateTimeObject_Type);
     if (obj == NULL) return NULL;
 
@@ -187,7 +198,11 @@ static char psyco_BufferObject__doc__[] =
 "Object to pass (in a portable way) binary data to the database.";
 
 PyTypeObject psyco_BufferObject_Type = {
+#ifndef _WIN32
     PyObject_HEAD_INIT(&PyType_Type)
+#else
+    PyObject_HEAD_INIT(NULL)
+#endif
     0,				                    /*ob_size*/
     "buffer",                           /*tp_name*/
     sizeof(psyco_BufferObject),	     	/*tp_basicsize*/
@@ -219,7 +234,11 @@ new_psyco_bufferobject(PyObject *buffer)
     unsigned char *original, *quoted, *chptr, *newptr;
     int i, len, space, new_space;
 
-    
+#ifdef _WIN32
+    /* For MSVC workaround */
+    psyco_BufferObject_Type.ob_type = &PyType_Type;
+#endif
+
     obj = PyObject_NEW(psyco_BufferObject, &psyco_BufferObject_Type);
     if (obj == NULL) return NULL;
 
@@ -229,7 +248,7 @@ new_psyco_bufferobject(PyObject *buffer)
 
     Py_BEGIN_ALLOW_THREADS;
 
-    quoted = (char*)calloc(space, sizeof(char));
+    quoted = (unsigned char*)calloc(space, sizeof(char));
     if (quoted == NULL) return NULL;
 
     chptr = quoted;
@@ -241,7 +260,7 @@ new_psyco_bufferobject(PyObject *buffer)
             new_space  =  space * ((space) / (i + 1)) + 2 + 6;
             if (new_space - space < 1024) space += 1024;
             else space = new_space;
-            newptr = (char *)realloc(quoted, space);
+            newptr = (unsigned char *)realloc(quoted, space);
             if (newptr == NULL) {
                 free(quoted);
                 return NULL;
@@ -358,7 +377,11 @@ static char psyco_QuotedStringObject__doc__[] =
 "A string that quotes itself following PostgreSQL quoting convention.";
 
 PyTypeObject psyco_QuotedStringObject_Type = {
+#ifndef _WIN32
     PyObject_HEAD_INIT(&PyType_Type)
+#else
+    PyObject_HEAD_INIT(NULL)
+#endif
     0,				                    /*ob_size*/
     "buffer",                           /*tp_name*/
     sizeof(psyco_QuotedStringObject),   /*tp_basicsize*/
@@ -389,14 +412,22 @@ new_psyco_quotedstringobject(PyObject *buffer)
     psyco_QuotedStringObject *obj;
     char *original, *quoted;
     int i, j, len;
-    
-    obj = PyObject_NEW(psyco_QuotedStringObject, &psyco_QuotedStringObject_Type);
+
+#ifdef _WIN32
+    /* For MSVC workaround */
+    psyco_QuotedStringObject_Type.ob_type = &PyType_Type;
+#endif
+
+    obj = PyObject_NEW(psyco_QuotedStringObject,
+                       &psyco_QuotedStringObject_Type);
     if (obj == NULL) return NULL;
 
     original = PyString_AS_STRING(buffer);
     len = PyString_GET_SIZE(buffer);
+
+    Dprintf("new_psyco_quotedstringobject: len = %d\n", len);
     
-    quoted = (char*)malloc(len*2+2);
+    quoted = (char*)malloc(len*2+3);
     if (quoted == NULL) return NULL;
 
     for (i=0, j=1; i<len; i++) {
@@ -421,9 +452,9 @@ new_psyco_quotedstringobject(PyObject *buffer)
     quoted[j] = '\0';
 
     /* are we overwriting someone else memory? */
-    assert(j < len*2+2);
+    assert(j < len*2+3);
         
-    Dprintf("new_psyco_quotedstringobject(): quoted = %s\n", quoted);
+    Dprintf("new_psyco_quotedstringobject: quoted = %s\n", quoted);
 
     obj->buffer = PyString_FromStringAndSize(quoted, j);
     free(quoted);
