@@ -20,7 +20,7 @@
 
 /*
  * typeobj.c -- define the type objects
- * $Id: typeobj.c,v 1.20.2.8 2002/03/29 12:53:25 fog Exp $
+ * $Id: typeobj.c,v 1.20.2.9 2002/04/21 22:58:52 fog Exp $
  */
 
 #include "assert.h"
@@ -579,7 +579,11 @@ psyco_DBAPITypeObject_call(PyObject *self, PyObject *args, PyObject *keywds)
 static char psyco_DBAPITypeObject__doc__[] = "Object to classify data types.";
 
 PyTypeObject psyco_DBAPITypeObject_Type = {
+#ifndef _WIN32
     PyObject_HEAD_INIT(&PyType_Type)
+#else
+    PyObject_HEAD_INIT(NULL)
+#endif
     0,				                    /*ob_size*/
     "type",         		            /*tp_name*/
     sizeof(psyco_DBAPITypeObject),		/*tp_basicsize*/
@@ -608,7 +612,12 @@ static PyObject *
 psyco_DBAPITypeObject_new(PyObject *name, PyObject *values, PyObject *cast)
 {
     psyco_DBAPITypeObject *obj;
-    
+
+#ifdef _WIN32
+    /* For MSVC workaround */
+    psyco_DBAPITypeObject_Type.ob_type = &PyType_Type;
+#endif
+
     obj = PyObject_NEW(psyco_DBAPITypeObject, &psyco_DBAPITypeObject_Type);
     if (obj == NULL) return NULL;
 
